/* rexx */
trace n

INSTALL = ""
do while INSTALL = ""
   say 'Enter fully qualified name of distributed PGP dataset' ,
       'without quotes'
   parse pull INSTALL
   INSTALL = strip(INSTALL)
   rc = listdsi("'"INSTALL"'")
   if rc <> 0 then do
      say "Unable to find dataset "INSTALL
      say "Install aborted"
      exit 12
   end
end

if SYSDSORG <> "PS" then do
   say "The dataset is not sequential - it is "SYSDSORG
   say "This dataset should have the following DCB information"
   say " LRECL=80 RECFM=FB BLKSIZE=3120 DSORG=PS"
   say "Install aborted"
   exit 12
end

if SYSRECFM <> "FB" then do
   say "The dataset is not fixed block - it is "SYSRECFM
   say "This dataset should have the following DCB information"
   say " LRECL=80 RECFM=FB BLKSIZE=3120 DSORG=PS"
   say "Install aborted"
   exit 12
end

if SYSLRECL <> 80 then do
   say "The dataset has a record length of " SYSLRECL
   say "This dataset should have the following DCB information"
   say " LRECL=80 RECFM=FB BLKSIZE=3120 DSORG=PS"
   say "Install aborted"
   exit 12
end

if SYSBLKSIZE > 3120 then do
   say "The dataset has a blocksize of " SYSBLKSIZE
   say "This dataset should have the following DCB information"
   say " LRECL=80 RECFM=FB BLKSIZE=3120 DSORG=PS"
   say "Install aborted"
   exit 12
end

HLQ = ""
do while HLQ = ""
  say 'Enter high level qualifier for PGP datasets without quotes'
  parse pull HLQ
  HLQ = strip(HLQ)
end

instds = HLQ".INSTALL"
upper instds
loadds = HLQ".LOAD"
upper loadds
sampds = HLQ".SAMPLIB"
upper sampds
say instds loadds sampds
address tso
allocinst = 0
allocload = 0
allocsamp = 0

dsstatus1 = sysdsn("'"instds"'")
if dsstatus1 <> "OK" & dsstatus1 <> "DATASET NOT FOUND" then do
   say " The high level qualifer is invalid - " dsstatus1
   say " The dataset name generated would be " instds
   say " Install aborted"
   exit 12
end
dsstatus2 = sysdsn("'"loadds"'")
if dsstatus2 <> "OK" & dsstatus2 <> "DATASET NOT FOUND" then do
   say " The high level qualifer is invalid - " dsstatus2
   say " The dataset name generated would be " loadds
   say " Install aborted"
   exit 12
end
dsstatus3 = sysdsn("'"sampds"'")
if dsstatus3 <> "OK" & dsstatus3 <> "DATASET NOT FOUND" then do
   say " The high level qualifer is invalid - " dsstatus3
   say " The dataset name generated would be " sampds
   say " Install aborted"
   exit 12
end

Alloc1 = "da('"instds"') shr"
Alloc2 = "da('"loadds"') shr"
Alloc3 = "da('"sampds"') shr"

if dsstatus1 = "DATASET NOT FOUND" | ,
   dsstatus2 = "DATASET NOT FOUND" | ,
   dsstatus3 = "DATASET NOT FOUND" then do
   say 'Obtaining allocation parameters for datasets'
   say 'Enter the name of the volume (Hit ENTER for default)'
   parse pull VOL1
   say 'Enter the unit name for the volume (Hit ENTER for default)'
   parse pull UNIT1
   say 'Enter the sms storage class to be used (Hit ENTER for default)'
   parse pull SMS1
   address TSO
   if dsstatus1 <> "OK" then do
      Alloc1 = "da('"instds"') cyl dir(100) space(100) new "
      if (VOL1 <> "") then do
         Alloc1 = Alloc1 || " vol(" || VOL1 || ")"
      end
      if (UNIT1 <> "") then do
         Alloc1 = Alloc1 || " unit(" || UNIT1 || ")"
      end
      if (SMS1 <> "") then do
         Alloc1 = Alloc1 || " storclas(" || SMS1 || ")"
      end
      allocinst = 1
   end

   if dsstatus2 <> "OK" then do
      Alloc2 = "da('"loadds"') cyl dir(10) space(50) new "
      if (VOL1 <> "") then do
         Alloc2 = Alloc2 || " vol(" || VOL1 || ")"
      end
      if (UNIT1 <> "") then do
         Alloc2 = Alloc2 || " unit(" || UNIT1 || ")"
      end
      if (SMS1 <> "") then do
         Alloc2 = Alloc2 || " storclas(" || SMS1 || ")"
      end
      allocload = 1
   end

   if dsstatus3 <> "OK" then do
      Alloc3 = "da('"sampds"') cyl dir(20) space(10) new "
      if (VOL1 <> "") then do
         Alloc3 = Alloc3 || " vol(" || VOL1 || ")"
      end
      if (UNIT1 <> "") then do
         Alloc3 = Alloc3 || " unit(" || UNIT1 || ")"
      end
      if (SMS1 <> "") then do
         Alloc3 = Alloc3 || " storclas(" || SMS1 || ")"
      end
      allocsamp = 1
   end
end


say
say "Restoring install library"
say
address tso
queue Alloc1
x=msg('off')
x=prompt('on')
x=outtrap('msg.','*')
"receive inda('"INSTALL"')"
x=outtrap('off')
if RC <> 0 then do
   do i = 1 to msg.0
      say msg.i
   end
   say "Receive of "instds" failed"
   say "exec aborted"
   if allocinst=1 then do
      "delete '"instds"'"
   end
   if allocsamp=1 then do
      "delete '"sampds"'"
   end
   if allocload=1 then do
      "delete '"loadds"'"
   end
   exit 12
end
x=msg('on')

say
say "Restoring load library"
say
address tso
queue Alloc2
x=msg('off')
x=prompt('on')
x=outtrap('msg.','*')
"receive inda('"instds"(LOAD)')"
x=outtrap('off')
if RC <> 0 then do
   do i = 1 to msg.0
      say msg.i
   end
   say "Receive of "loadds" failed"
   say "exec aborted"
   if allocinst=1 then do
      "delete '"instds"'"
   end
   if allocsamp=1 then do
      "delete '"sampds"'"
   end
   if allocload=1 then do
      "delete '"loadds"'"
   end
   exit 12
end
x=msg('on')

say
say "Restoring sample library"
say
address tso
queue Alloc3
x=msg('off')
x=prompt('on')
x=outtrap('msg.','*')
"receive inda('"instds"(SAMPLIB)')"
x=outtrap('off')
if RC <> 0 then do
   do i = 1 to msg.0
      say msg.i
   end
   say "Receive of "sampds" failed"
   say "exec aborted"
   if allocinst=1 then do
      "delete '"instds"'"
   end
   if allocsamp=1 then do
      "delete '"sampds"'"
   end
   if allocload=1 then do
      "delete '"loadds"'"
   end
   exit 12
end
x=msg('on')

"delete '"instds"'"
say
say "PGP has been installed to "loadds" and "sampds
say
